package simulations

import io.gatling.core.Predef.{jsonPath, _}
import io.gatling.http.Predef._

class SampleSimulation extends Simulation {

  val protocols = http
    .disableCaching
    .disableWarmUp
    .baseUrl("https://reqres.in")

  val scn = scenario("sample scenario")
    .exec(session => session.set("id", 1))
    .exec(http("get info for user id 1").get("/api/users/${id}")
      .check(
        status.is(200),
        status.not(400),
        status.in(200, 201),
        jsonPath("$.data.id").ofType[Int].is(session => session("id").as[Int]),
        jsonPath("$.data.first_name").transform(str => str.trim).saveAs("first_name"),
        jsonPath("$.data.last_name").transform((str, session) => str.trim + " " + session("first_name").as[String]).saveAs("full_name")
      ))

  setUp(scn.inject(atOnceUsers(1))).protocols(protocols)
}